@@ -4,7 +4,6 @@ from scipy import stats
 
 from .native.pyrisk import python_estimate_downside_risk, python_estimate_upside_risk
 from .native.cythonrisk import cython_estimate_downside_risk, cython_estimate_upside_risk
-from .native.fortranrisk import fortranrisk
 from .constants import dividing_factors_dict
 
 
@@ -18,11 +17,9 @@ def estimate_downside_risk(timestamps, prices, target_return, unit='year', lowle
         return cython_estimate_downside_risk(ts, prices, target_return)
     elif lowlevellang == 'P':
         return python_estimate_downside_risk(ts, prices, target_return)
-    elif lowlevellang == 'F':
-        return fortranrisk.fortran_estimate_downside_risk(ts, prices, target_return)
     else:
         raise ValueError(
-            'Unknown low-level language: {}. (Should be "P" (Python), "C" (Cython), or "F" (Fortran).)'.format(
+            'Unknown low-level language: {}. (Should be "P" (Python), or "C" (Cython))'.format(
                 lowlevellang))
 
 
@@ -36,11 +33,9 @@ def estimate_upside_risk(timestamps, prices, target_return, unit='year', lowleve
         return cython_estimate_upside_risk(ts, prices, target_return)
     elif lowlevellang == 'N':
         return python_estimate_upside_risk(ts, prices, target_return)
-    elif lowlevellang == 'F':
-        return fortranrisk.fortran_estimate_upside_risk(ts, prices, target_return)
     else:
         raise ValueError(
-            'Unknown low-level language: {}. (Should be "P" (Python), "C" (Cython), or "F" (Fortran).)'.format(
+            'Unknown low-level language: {}. (Should be "P" (Python), or "C" (Cython).)'.format(
                 lowlevellang))
 
 
